<?php

use Hackersnews\Repository\PostsRepositoryInterface;
use Hackersnews\Validator\NewsValidator;
use Hackersnews\Repository\VotesRepositoryInterface;

class NewsController extends BaseController {

    public function __construct(PostsRepositoryInterface $news, NewsValidator $validator, VotesRepositoryInterface $votes)
    {
        $this->news = $news;
        $this->validator = $validator;
        $this->votes = $votes;
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        return View::make('post/submit');
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        if ( ! $this->validator->validCreate(Input::all()))
        {
            return Redirect::back()->withInput()->withErrors($this->validator->errors());
        }
        $news = $this->news->create('news', Input::all());

        return Redirect::route('news', array('id' => $news->id, 'slug' => $news->slug));
    }


    public function show($id, $slug = null)
    {
        $post = $this->news->getById($id, 'news');
        if ( ! $post || ! $post->approved_at)
        {
            return Redirect::route('trending')->with('flashError', t('Nothing Found'));
        }
        if ($slug != $post->slug)
        {
            return Redirect::route('news', array('id' => $post->id, 'slug' => $post->slug));
        }
        Event::fire('posts.views', $post);
        $comments = $post->comments()->with('votes', 'votes.user', 'user', 'reply', 'reply.user', 'reply.comment', 'reply.votes', 'reply.votes.user')->orderBy('created_at', 'desc')->paginate(perPage());
        $title = t('News');

        return View::make('post/post', compact('post', 'comments', 'title'));
    }


    public function getTrending()
    {
        $posts = $this->news->getTrending('news', Input::get('category'));
        $title = t('Trending News');

        return View::make('post.list', compact('posts', 'title'));
    }

    public function getLatest()
    {
        $posts = $this->news->getLatest('news', Input::get('category'));
        $title = t('Latest News');

        return View::make('post.list', compact('posts', 'title'));
    }

    public function getFeatured()
    {
        $posts = $this->news->getFeatured('news', Input::get('category'));
        $title = t('Featured News');

        return View::make('post.list', compact('posts', 'title'));
    }

    public function vote()
    {
        $id = Input::get('id');

        if ( ! $id)
            return Response::make('error', 404);

        $news = $this->news->getAnyById($id);

        if ( ! $news)
            return Response::make('error', 404);

        $voted = $news->votes()->whereUserId(Auth::user()->id)->first();
        if ( ! $voted)
        {
            $this->votes->vote($news);
        }
        else
        {
            $voted->delete();
        }

        return Response::make($news->votes()->count(), 200);
    }

    public function edit($id)
    {
        $post = $this->news->getById($id);
        $title = 'Editing';
        if ( ! $post || $post->user->id !== Auth::user()->id)
        {
            return Redirect::route('home')->with('flashError', t('Nothing Found'));
        }

        return View::make('post/edit', compact('post', 'title'));
    }

    public function postEdit($id)
    {
        $post = $this->news->getById($id);

        if ( ! $this->validator->validEdit(Input::all()))
        {
            return Redirect::back()->withInput()->withErrors($this->validator->errors());
        }

        $news = $this->news->edit($post, Input::all());
        if (Input::get('delete'))
        {
            return Redirect::route('home')->with('flashSuccess', t('Post is now deleted'));
        }

        return Redirect::route('news', array('id' => $news->id, 'slug' => $news->slug))->with('flashSuccess', t('Post is now update'));
    }
}
