<?php

/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */
use Hackersnews\Repository\PostsRepositoryInterface;
use Hackersnews\Validator\QuestionsValidator;

class QuestionsController extends BaseController {

    public function __construct(PostsRepositoryInterface $question, QuestionsValidator $validator)
    {
        $this->question = $question;
        $this->validator = $validator;
    }

    public function index()
    {
        return View::make('questions/submit');
    }

    public function create()
    {
        if ( ! $this->validator->validCreate(Input::all()))
        {
            return Redirect::back()->withInput()->withErrors($this->validator->errors());
        }
        $question = $this->question->create('question', Input::all());

        return Redirect::route('question', array('id' => $question->id, 'slug' => $question->slug));
    }

    public function get($id, $slug = null)
    {
        $post = $this->question->getById($id, 'question');
        if ( ! $post || ! $post->approved_at)
        {
            return Redirect::route('trending')->with('flashError', t('Nothing Found'));
        }
        if ($slug != $post->slug)
        {
            return Redirect::route('question', array('id' => $post->id, 'slug' => $post->slug));
        }
        Event::fire('posts.views', $post);
        $comments = $post->comments()->with('votes' , 'votes.user', 'user', 'reply', 'reply.user', 'reply.comment', 'reply.votes', 'reply.votes.user')->orderBy('created_at', 'desc')->paginate(perPage());
        $title = t('Question');

        return View::make('post/post', compact('post', 'comments', 'title'));
    }

    public function getLatest()
    {
        $posts = $this->question->getLatest('question', Input::get('category'));
        $title = t('Latest Questions');

        return View::make('post/list', compact('posts', 'title'));
    }


    public function getTrending()
    {
        $posts = $this->question->getTrending('question', Input::get('category'));
        $title = t('Trending Questions');

        return View::make('post/list', compact('posts', 'title'));
    }

    public function getFeatured()
    {
        $posts = $this->question->getFeatured('question', Input::get('category'));
        $title = t('Featured Questions');

        return View::make('post/list', compact('posts', 'title'));
    }

    public function edit($id)
    {
        $post = $this->question->getById($id);
        $title = 'Editing ' . $post->title;
        if ( ! $post || $post->user->id !== Auth::user()->id)
        {
            return Redirect::route('home')->with('flashError', t('Nothing Found'));
        }

        return View::make('post/edit', compact('post', 'title'));
    }

    public function postEdit($id)
    {
        $post = $this->question->getById($id);

        if ( ! $this->validator->validEdit(Input::all()))
        {
            return Redirect::back()->withInput()->withErrors($this->validator->errors());
        }

        $post = $this->question->edit($post, Input::all());

        if (Input::get('delete'))
        {
            return Redirect::route('home')->with('flashSuccess', t('Post is now deleted'));
        }

        return Redirect::route('question', array('id' => $post->id, 'slug' => $post->slug))->with('flashSuccess', t('Post is now update'));
    }
}