<?php
/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */
namespace Hackersnews\Repository\Eloquent;

use Carbon\Carbon;
use Hackersnews\Mailers\UserMailer;
use Hackersnews\Repository\UsersRepositoryInterface;
use User;
use Hash, Auth;

class UsersRepository extends AbstractRepository implements UsersRepositoryInterface {

    /**
     * @var \Hackersnews\Mailers\Mailer
     */
    private $mailer;
    /**
     * @var \User
     */
    private $user;

    /**
     * @param User                            $user
     * @param \Hackersnews\Mailers\UserMailer $mailer
     */
    public function __construct(User $user, UserMailer $mailer)
    {

        $this->mailer = $mailer;
        $this->model = $user;
    }

    /**
     * @param $id
     * @return mixed
     */
    public function getById($id)
    {
        $user = $this->model->whereId($id)->first();

        return $user;
    }

    /**
     * @param $username
     * @return mixed
     */
    public function getByUsername($username)
    {
        $user = $this->model->whereUsername($username)->first();

        return $user;
    }

    /**
     * @param $input
     * @return bool
     */
    public function updatePassword($input)
    {
        if (Hash::check($input['currentpassword'], Auth::user()->password))
        {
            $user = Auth::user();
            $user->password = Hash::make($input['password']);
            $user->save();

            return true;
        }
        else
        {
            return false;
        }
    }


    /**
     * @param array $input
     * @return bool
     */
    public function create(array $input)
    {
        $activationCode = sha1(str_random(11) . (time() * rand(2, 2000)));

        $this->model->username = $input['username'];
        $this->model->fullname = $input['fullname'];
        $this->model->gender = $input['gender'];
        $this->model->email = $input['email'];
        $this->model->password = Hash::make($input['password']);
        $this->model->confirmed = $activationCode;
        $this->model->save();

        $this->mailer->activation($this->model, $activationCode);

        return true;
    }

    /**
     * @param $username
     * @param $activationCode
     * @return bool
     */
    public function activate($username, $activationCode)
    {
        $user = $this->model->where('username', '=', $username)->first();
        if ($user->confirmed === $activationCode)
        {
            $user->confirmed = 1;
            $user->save();

            return true;
        }

        return false;
    }

    /**
     * @param $id
     * @return mixed
     */
    public function notifications($id)
    {
        $user = $this->model->whereId($id)->with('notifications')->first();
        $notices = $user->notifications()->orderBy('created_at', 'desc')->paginate(perPage());
        foreach ($notices as $notice)
        {
            if ( ! $notice->seen_at)
            {
                $notice->seen_at = Carbon::now();
                $notice->save();
            }


        }

        return $notices;
    }


    /**
     * @param array $input
     * @param null  $session
     * @return bool
     */
    public function createFacebookUser(array $input, $session = null)
    {
        if ( ! $session) return;
        $user = $this->getNew();
        $user->username = $input['username'];
        $user->password = Hash::make($input['password']);
        $user->fbid = $session['id'];
        $user->email = $session['email'];
        if ($session['gender'])
            $user->gender = $session['gender'];
        $user->fullname = $session['name'];
        $user->confirmed = 1;
        $user->save();
        Auth::loginUsingId($user->id);

        return true;
    }

    /**
     * @param array $input
     * @param null  $session
     * @return bool
     */
    public function createGoogleUser(array $input, $session = null)
    {
        if ( ! $session) return;
        $user = $this->getNew();
        $user->username = $input['username'];
        $user->password = Hash::make($input['password']);
        $user->gid = $session['id'];
        $user->email = $session['email'];
        if ($session['gender'])
            $user->gender = $session['gender'];
        $user->fullname = $session['name'];
        $user->confirmed = 1;
        $user->save();
        Auth::loginUsingId($user->id);

        return true;
    }
}