<?php

/**
 * @author Abhimanyu Sharma <abhimanyusharma003@gmail.com>
 */
namespace Hackersnews\Repository;

use Post;

interface PostsRepositoryInterface {

    /**
     * @param      $id
     * @param null $type
     * @return mixed
     */
    public function getById($id, $type = null);

    /**
     * @param $id
     * @return mixed
     */
    public function getAnyById($id);

    /**
     * @param null $type
     * @param null $category
     * @return mixed
     */
    public function getTrending($type = null, $category = null);

    /**
     * @param null   $type
     * @param null   $category
     * @param string $order
     * @return mixed
     */
    public function getLatest($type = null, $category = null, $order = 'desc');

    /**
     * @param null $type
     * @param null $category
     * @return mixed
     */
    public function getFeatured($type = null, $category = null);


    /**
     * @param $news
     * @return mixed
     */
    public function incrementViews($news);

    /**
     * @param      $term
     * @param null $type
     * @param null $category
     * @return mixed
     */
    public function search($term, $type = null, $category = null);

    /**
     * @param       $type
     * @param array $input
     * @return mixed
     */
    public function create($type, array $input);

    /**
     * @param Post  $posts
     * @param array $input
     * @return Post
     */
    public function edit(Post $posts, array $input);

    //@todo add filter for admin panel
    /**
     * @return mixed
     */
    public function getApprovalRequired();

    /**
     * Admin helper, gives output irr-respective of post approved or not
     *
     * @param $id
     * @return mixed
     */
    public function getByIdForAdmin($id);

    /**
     * Admin helper, to edit post irr-respective of post approved or not
     *
     * @param Post  $posts
     * @param array $input
     * @return Post
     */
    public function adminEdit(Post $posts, array $input);
}